pub struct SessionStateMachine { /* private fields */ }Implementations
Sourceimpl SessionStateMachine
impl SessionStateMachine
pub fn new(init: SessionInit) -> Self
pub fn phase(&self) -> &SessionPhase
pub fn session_id(&self) -> Option<AgentID>
pub fn endpoints( &self, ) -> Option<&HashMap<AgentCapabilities, TransportProtocolEndpoint>>
pub fn last_error(&self) -> Option<&str>
Sourcepub fn start_connect(&mut self, now_ms: NowMs) -> Vec<SessionAction>
pub fn start_connect(&mut self, now_ms: NowMs) -> Vec<SessionAction>
Begin connection orchestration. Returns the initial actions.
Sourcepub fn start_deregister(&mut self, reason: Option<String>) -> Vec<SessionAction>
pub fn start_deregister(&mut self, reason: Option<String>) -> Vec<SessionAction>
Request a graceful deregistration. Returns actions to perform now.
Sourcepub fn step(
&mut self,
now_ms: NowMs,
events: &[SessionEvent],
) -> Vec<SessionAction>
pub fn step( &mut self, now_ms: NowMs, events: &[SessionEvent], ) -> Vec<SessionAction>
Advance the state machine by providing observed events.
Sourcepub fn try_mark_data_channels_active(
&mut self,
sensor_state: &FeagiEndpointState,
motor_state: &FeagiEndpointState,
)
pub fn try_mark_data_channels_active( &mut self, sensor_state: &FeagiEndpointState, motor_state: &FeagiEndpointState, )
Helper for drivers: after polling sensor and motor channels, call this to decide if data channels are fully active and transition to Active.