pub struct RegistrationRequest { /* private fields */ }Implementations
Sourceimpl RegistrationRequest
impl RegistrationRequest
Sourcepub const MAX_REQUEST_SIZE: usize = 1024
pub const MAX_REQUEST_SIZE: usize = 1024
No request should be bigger than this many bytes. If so, assume something malicious is going on
Sourcepub fn new(
agent_descriptor: AgentDescriptor,
auth_token: AuthToken,
requested_capabilities: Vec<AgentCapabilities>,
connection_protocol: TransportProtocolImplementation,
) -> Self
pub fn new( agent_descriptor: AgentDescriptor, auth_token: AuthToken, requested_capabilities: Vec<AgentCapabilities>, connection_protocol: TransportProtocolImplementation, ) -> Self
Create a new registration request.
Arguments
agent_descriptor- Information identifying the agentauth_token- Authentication token for secure accessrequested_capabilities- List of capabilities the agent is requestingconnection_protocol- The protocol the agent wants to use for communication
Sourcepub fn api_version(&self) -> &FeagiApiVersion
pub fn api_version(&self) -> &FeagiApiVersion
Get the reported API version
Sourcepub fn agent_descriptor(&self) -> &AgentDescriptor
pub fn agent_descriptor(&self) -> &AgentDescriptor
Get the agent descriptor.
Sourcepub fn auth_token(&self) -> &AuthToken
pub fn auth_token(&self) -> &AuthToken
Get the authentication token.
Sourcepub fn requested_capabilities(&self) -> &[AgentCapabilities]
pub fn requested_capabilities(&self) -> &[AgentCapabilities]
Get the requested capabilities.
Sourcepub fn connection_protocol(&self) -> &TransportProtocolImplementation
pub fn connection_protocol(&self) -> &TransportProtocolImplementation
Get the connection protocol.